@@ -5,12 +5,12 @@ import (
 	"fmt"
 	"math"
 	"reflect"
-	"sort"
 
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
 
+	"github.com/davegardnerisme/deephash"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
@@ -43,6 +43,8 @@ const (
 	clusterPoolAdminRoleName        = "hive-cluster-pool-admin"
 	clusterPoolAdminRoleBindingName = "hive-cluster-pool-admin-binding"
 	icSecretDependent               = "install config template secret"
+	cdClusterPoolIndex              = "spec.clusterpool.namespacedname"
+	claimClusterPoolIndex           = "spec.clusterpoolname"
 )
 
 var (
@@ -53,9 +55,14 @@ var (
 	clusterPoolConditions = []hivev1.ClusterPoolConditionType{
 		hivev1.ClusterPoolMissingDependenciesCondition,
 		hivev1.ClusterPoolCapacityAvailableCondition,
+		hivev1.ClusterPoolAllClustersCurrentCondition,
 	}
 )
 
+func poolKey(namespace, name string) string {
+	return namespace + "/" + name
+}
+
 // Add creates a new ClusterPool Controller and adds it to the Manager with default RBAC. The Manager will set fields on the Controller
 // and Start it when the Manager is Started.
 func Add(mgr manager.Manager) error {
@@ -90,6 +97,32 @@ func AddToManager(mgr manager.Manager, r *ReconcileClusterPool, concurrentReconc
 		return err
 	}
 
+	// Index ClusterDeployments by pool namespace/name
+	if err := mgr.GetFieldIndexer().IndexField(context.TODO(), &hivev1.ClusterDeployment{}, cdClusterPoolIndex,
+		func(o client.Object) []string {
+			cd := o.(*hivev1.ClusterDeployment)
+			if poolRef := cd.Spec.ClusterPoolRef; poolRef != nil {
+				return []string{poolKey(poolRef.Namespace, poolRef.PoolName)}
+			}
+			return []string{}
+		}); err != nil {
+		log.WithError(err).Error("Error indexing ClusterDeployments by ClusterPool")
+		return err
+	}
+
+	// Index ClusterClaims by pool name
+	if err := mgr.GetFieldIndexer().IndexField(context.TODO(), &hivev1.ClusterClaim{}, claimClusterPoolIndex,
+		func(o client.Object) []string {
+			claim := o.(*hivev1.ClusterClaim)
+			if poolName := claim.Spec.ClusterPoolName; poolName != "" {
+				return []string{poolName}
+			}
+			return []string{}
+		}); err != nil {
+		log.WithError(err).Error("Error indexing ClusterClaims by ClusterPool")
+		return err
+	}
+
 	// Watch for changes to ClusterPool
 	err = c.Watch(&source.Kind{Type: &hivev1.ClusterPool{}}, &handler.EnqueueRequestForObject{})
 	if err != nil {
@@ -202,7 +235,7 @@ type ReconcileClusterPool struct {
 // attempts to reach the desired state if not.
 func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	logger := controllerutils.BuildControllerLogger(ControllerName, "clusterPool", request.NamespacedName)
-	logger.Infof("reconciling cluster pool")
+	logger.Info("reconciling cluster pool")
 	recobsrv := hivemetrics.NewReconcileObserver(ControllerName, logger)
 	defer recobsrv.ObserveControllerReconcileTime()
 
@@ -224,7 +257,7 @@ func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.
 	newConditions := controllerutils.InitializeClusterPoolConditions(clp.Status.Conditions, clusterPoolConditions)
 	if len(newConditions) > len(clp.Status.Conditions) {
 		clp.Status.Conditions = newConditions
-		logger.Infof("initializing cluster pool conditions")
+		logger.Info("initializing cluster pool conditions")
 		if err := r.Status().Update(context.TODO(), clp); err != nil {
 			logger.WithError(err).Log(controllerutils.LogLevel(err), "failed to update cluster pool status")
 			return reconcile.Result{}, err
@@ -252,48 +285,24 @@ func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.
 		return reconcile.Result{}, nil
 	}
 
-	// Find all ClusterDeployments from this pool:
-	claimedCDs, unClaminedCDs, err := r.getAllClusterDeploymentsForPool(clp, logger)
+	poolVersion := calculatePoolVersion(clp)
+
+	cds, err := getAllClusterDeploymentsForPool(r.Client, clp, poolVersion, logger)
 	if err != nil {
 		return reconcile.Result{}, err
 	}
 
-	var toRemoveClaimedCDs []*hivev1.ClusterDeployment
-	numberOfDeletingClaimedCDs := 0
-	for _, cd := range claimedCDs {
-		toRemove := controllerutils.IsClaimedClusterMarkedForRemoval(cd)
-		switch {
-		case cd.DeletionTimestamp != nil:
-			numberOfDeletingClaimedCDs++
-		case toRemove:
-			toRemoveClaimedCDs = append(toRemoveClaimedCDs, cd)
-		}
+	claims, err := getAllClaimsForPool(r.Client, clp, logger)
+	if err != nil {
+		return reconcile.Result{}, err
 	}
 
-	var installingCDs []*hivev1.ClusterDeployment
-	var readyCDs []*hivev1.ClusterDeployment
-	numberOfDeletingCDs := 0
-	for _, cd := range unClaminedCDs {
-		switch {
-		case cd.DeletionTimestamp != nil:
-			numberOfDeletingCDs++
-		case !cd.Spec.Installed:
-			installingCDs = append(installingCDs, cd)
-		default:
-			readyCDs = append(readyCDs, cd)
-		}
-	}
-
-	logger.WithFields(log.Fields{
-		"installing": len(installingCDs),
-		"deleting":   numberOfDeletingCDs,
-		"total":      len(unClaminedCDs),
-		"ready":      len(readyCDs),
-	}).Debug("found clusters for ClusterPool")
+	claims.SyncClusterDeploymentAssignments(r.Client, cds, logger)
+	cds.SyncClaimAssignments(r.Client, claims, logger)
 
 	origStatus := clp.Status.DeepCopy()
-	clp.Status.Size = int32(len(installingCDs) + len(readyCDs))
-	clp.Status.Ready = int32(len(readyCDs))
+	clp.Status.Size = int32(len(cds.Installing()) + len(cds.Assignable()) + len(cds.Broken()))
+	clp.Status.Ready = int32(len(cds.Assignable()))
 	if !reflect.DeepEqual(origStatus, &clp.Status) {
 		if err := r.Status().Update(context.Background(), clp); err != nil {
 			logger.WithError(err).Log(controllerutils.LogLevel(err), "could not update ClusterPool status")
@@ -303,12 +312,14 @@ func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.
 
 	availableCapacity := math.MaxInt32
 	if clp.Spec.MaxSize != nil {
-		availableCapacity = int(*clp.Spec.MaxSize) - len(unClaminedCDs) - len(claimedCDs)
+		availableCapacity = int(*clp.Spec.MaxSize) - cds.Total()
+		numUnassigned := len(cds.Installing()) + len(cds.Assignable()) + len(cds.Broken())
+		numAssigned := cds.NumAssigned()
 		if availableCapacity <= 0 {
 			logger.WithFields(log.Fields{
-				"lUnclaimedSize": len(unClaminedCDs),
-				"ClaimedSize":    len(claimedCDs),
-				"Capacity":       *clp.Spec.MaxSize,
+				"UnclaimedSize": numUnassigned,
+				"ClaimedSize":   numAssigned,
+				"Capacity":      *clp.Spec.MaxSize,
 			}).Info("Cannot add more clusters because no capacity available.")
 		}
 	}
@@ -317,34 +328,29 @@ func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.
 		return reconcile.Result{}, err
 	}
 
-	pendingClaims, err := r.getAllPendingClusterClaims(clp, logger)
-	if err != nil {
-		return reconcile.Result{}, err
-	}
-	logger.WithField("count", len(pendingClaims)).Debug("found pending claims for ClusterPool")
-
 	// reserveSize is the number of clusters that the pool currently has in reserve
-	reserveSize := len(installingCDs) + len(readyCDs) - len(pendingClaims)
+	reserveSize := len(cds.Installing()) + len(cds.Assignable()) + len(cds.Broken()) - len(claims.Unassigned())
 
-	readyCDs, err = r.assignClustersToClaims(pendingClaims, readyCDs, logger)
-	if err != nil {
+	if err := assignClustersToClaims(r.Client, claims, cds, logger); err != nil {
+		logger.WithError(err).Error("error assigning clusters <=> claims")
 		return reconcile.Result{}, err
 	}
 
 	availableCurrent := math.MaxInt32
 	if clp.Spec.MaxConcurrent != nil {
-		availableCurrent = int(*clp.Spec.MaxConcurrent) - len(installingCDs) - numberOfDeletingCDs - numberOfDeletingClaimedCDs
+		availableCurrent = int(*clp.Spec.MaxConcurrent) - len(cds.Installing()) - len(cds.Deleting())
 		if availableCurrent < 0 {
 			availableCurrent = 0
 		}
 	}
 
 	// remove clusters that were previously claimed but now not required.
+	toRemoveClaimedCDs := cds.MarkedForDeletion()
 	toDel := minIntVarible(len(toRemoveClaimedCDs), availableCurrent)
 	for _, cd := range toRemoveClaimedCDs[:toDel] {
 		cdLog := logger.WithField("cluster", cd.Name)
 		cdLog.Info("deleting cluster deployment for previous claim")
-		if err := r.Client.Delete(context.Background(), cd); err != nil {
+		if err := cds.Delete(r.Client, cd.Name); err != nil {
 			cdLog.WithError(err).Error("error deleting cluster deployment")
 			return reconcile.Result{}, err
 		}
@@ -358,22 +364,50 @@ func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.
 			"MaxConcurrent": *clp.Spec.MaxConcurrent,
 			"Available":     availableCurrent,
 		}).Info("Cannot create/delete clusters as max concurrent quota exceeded.")
-	// If too many, delete some.
-	case drift > 0:
-		toDel := minIntVarible(drift, availableCurrent)
-		if err := r.deleteExcessClusters(installingCDs, readyCDs, toDel, logger); err != nil {
-			return reconcile.Result{}, err
-		}
 	// If too few, create new InstallConfig and ClusterDeployment.
 	case drift < 0:
 		if availableCapacity <= 0 {
 			break
 		}
 		toAdd := minIntVarible(-drift, availableCapacity, availableCurrent)
-		if err := r.addClusters(clp, toAdd, logger); err != nil {
+		// TODO: Do this in cdLookup so we can add the new CDs to Installing(). For now it's okay
+		// because the new CDs are guaranteed to have a matching PoolVersion, and that's the only
+		// thing we need to keep consistent.
+		if err := r.addClusters(clp, poolVersion, toAdd, logger); err != nil {
 			log.WithError(err).Error("error adding clusters")
 			return reconcile.Result{}, err
 		}
+	// Delete broken CDs. We put this case after the "addClusters" case because we would rather
+	// consume our maxConcurrent with additions than deletions. But we put it before the
+	// "deleteExcessClusters" case because we would rather trim broken clusters than viable ones.
+	case len(cds.Broken()) > 0:
+		if err := r.deleteBrokenClusters(cds, availableCurrent, logger); err != nil {
+			return reconcile.Result{}, err
+		}
+	// If too many, delete some.
+	case drift > 0:
+		toDel := minIntVarible(drift, availableCurrent)
+		if err := r.deleteExcessClusters(cds, toDel, logger); err != nil {
+			return reconcile.Result{}, err
+		}
+	// Special case for stale CDs: allow deleting one if all CDs are installed.
+	case drift == 0 && len(cds.Installing()) == 0 && len(cds.Stale()) > 0:
+		toDelete := cds.Stale()[0]
+		logger := logger.WithField("cluster", toDelete.Name)
+		logger.Info("deleting cluster deployment")
+		if err := cds.Delete(r.Client, toDelete.Name); err != nil {
+			logger.WithError(err).Error("error deleting cluster deployment")
+			return reconcile.Result{}, err
+		}
+		metricStaleClusterDeploymentsDeleted.WithLabelValues(clp.Namespace, clp.Name).Inc()
+	}
+
+	// One more (possible) status update: wait until the end to detect whether all unassigned CDs
+	// are current with the pool config, since assigning or deleting CDs may eliminate the last
+	// one that isn't.
+	if err := setCDsCurrentCondition(r.Client, cds, clp, poolVersion); err != nil {
+		log.WithError(err).Error("error updating 'ClusterDeployments current' status")
+		return reconcile.Result{}, err
 	}
 
 	if err := r.reconcileRBAC(clp, logger); err != nil {
@@ -384,6 +418,23 @@ func (r *ReconcileClusterPool) Reconcile(ctx context.Context, request reconcile.
 	return reconcile.Result{}, nil
 }
 
+// calculatePoolVersion computes a hash of the important (to ClusterDeployments) fields of the
+// ClusterPool.Spec. This is annotated on ClusterDeployments when the pool creates them, which
+// subsequently allows us to tell whether all unclaimed CDs are up to date and set a condition
+// accordingly.
+// NOTE: If we change this algorithm, we're guaranteed to think that all CDs are stale at the
+// moment that code update rolls out. We may wish to consider a way to support detecting the old
+// value as "current" in that case.
+func calculatePoolVersion(clp *hivev1.ClusterPool) string {
+	ba := []byte{}
+	ba = append(ba, deephash.Hash(clp.Spec.Platform)...)
+	ba = append(ba, deephash.Hash(clp.Spec.BaseDomain)...)
+	ba = append(ba, deephash.Hash(clp.Spec.ImageSetRef)...)
+	ba = append(ba, deephash.Hash(clp.Spec.InstallConfigSecretTemplateRef)...)
+	// Hash of hashes to ensure fixed length
+	return fmt.Sprintf("%x", deephash.Hash(ba))
+}
+
 func minIntVarible(v1 int, vn ...int) (m int) {
 	m = v1
 	for i := 0; i < len(vn); i++ {
@@ -494,6 +545,7 @@ func (r *ReconcileClusterPool) applyRoleBinding(desired, observed *rbacv1.RoleBi
 
 func (r *ReconcileClusterPool) addClusters(
 	clp *hivev1.ClusterPool,
+	poolVersion string,
 	newClusterCount int,
 	logger log.FieldLogger,
 ) error {
@@ -533,7 +585,7 @@ func (r *ReconcileClusterPool) addClusters(
 	}
 
 	for i := 0; i < newClusterCount; i++ {
-		if err := r.createCluster(clp, cloudBuilder, pullSecret, installConfigTemplate, logger); err != nil {
+		if err := r.createCluster(clp, cloudBuilder, pullSecret, installConfigTemplate, poolVersion, logger); err != nil {
 			return err
 		}
 	}
@@ -546,6 +598,7 @@ func (r *ReconcileClusterPool) createCluster(
 	cloudBuilder clusterresource.CloudBuilder,
 	pullSecret string,
 	installConfigTemplate string,
+	poolVersion string,
 	logger log.FieldLogger,
 ) error {
 	ns, err := r.createRandomNamespace(clp)
@@ -555,6 +608,13 @@ func (r *ReconcileClusterPool) createCluster(
 	}
 	logger.WithField("cluster", ns.Name).Info("Creating new cluster")
 
+	annotations := clp.Spec.Annotations
+	// Annotate the CD so we can distinguish "stale" CDs
+	if annotations == nil {
+		annotations = map[string]string{}
+	}
+	annotations[constants.ClusterDeploymentPoolSpecHashAnnotation] = poolVersion
+
 	// We will use this unique random namespace name for our cluster name.
 	builder := &clusterresource.Builder{
 		Name:                  ns.Name,
@@ -566,7 +626,7 @@ func (r *ReconcileClusterPool) createCluster(
 		PullSecret:            pullSecret,
 		CloudBuilder:          cloudBuilder,
 		Labels:                clp.Spec.Labels,
-		Annotations:           clp.Spec.Annotations,
+		Annotations:           annotations,
 		InstallConfigTemplate: installConfigTemplate,
 		SkipMachinePools:      clp.Spec.SkipMachinePools,
 	}
@@ -621,20 +681,16 @@ func (r *ReconcileClusterPool) createRandomNamespace(clp *hivev1.ClusterPool) (*
 }
 
 func (r *ReconcileClusterPool) deleteExcessClusters(
-	installingClusters []*hivev1.ClusterDeployment,
-	readyClusters []*hivev1.ClusterDeployment,
+	cds *cdCollection,
 	deletionsNeeded int,
 	logger log.FieldLogger,
 ) error {
 
 	logger.WithField("deletionsNeeded", deletionsNeeded).Info("deleting excess clusters")
 	clustersToDelete := make([]*hivev1.ClusterDeployment, 0, deletionsNeeded)
+	installingClusters := cds.Installing()
+	readyClusters := cds.Assignable()
 	if deletionsNeeded < len(installingClusters) {
-		// Sort the installing clusters in order by creation timestamp from newest to oldest. This has the effect of
-		// prioritizing deleting those clusters that have the longest time until they are installed.
-		sort.Slice(installingClusters, func(i, j int) bool {
-			return installingClusters[i].CreationTimestamp.After(installingClusters[j].CreationTimestamp.Time)
-		})
 		clustersToDelete = installingClusters[:deletionsNeeded]
 	} else {
 		clustersToDelete = append(clustersToDelete, installingClusters...)
@@ -652,7 +708,7 @@ func (r *ReconcileClusterPool) deleteExcessClusters(
 	for _, cd := range clustersToDelete {
 		logger := logger.WithField("cluster", cd.Name)
 		logger.Info("deleting cluster deployment")
-		if err := r.Client.Delete(context.Background(), cd); err != nil {
+		if err := cds.Delete(r.Client, cd.Name); err != nil {
 			logger.WithError(err).Error("error deleting cluster deployment")
 			return err
 		}
@@ -661,19 +717,35 @@ func (r *ReconcileClusterPool) deleteExcessClusters(
 	return nil
 }
 
+func (r *ReconcileClusterPool) deleteBrokenClusters(cds *cdCollection, maxToDelete int, logger log.FieldLogger) error {
+	numToDel := minIntVarible(maxToDelete, len(cds.Broken()))
+	logger.WithField("numberToDelete", numToDel).Info("deleting broken clusters")
+	clustersToDelete := make([]*hivev1.ClusterDeployment, numToDel)
+	copy(clustersToDelete, cds.Broken()[:numToDel])
+	for _, cd := range clustersToDelete {
+		logger.WithField("cluster", cd.Name).Info("deleting broken cluster deployment")
+		if err := cds.Delete(r.Client, cd.Name); err != nil {
+			logger.WithError(err).Error("error deleting cluster deployment")
+			return err
+		}
+	}
+	return nil
+}
+
 func (r *ReconcileClusterPool) reconcileDeletedPool(pool *hivev1.ClusterPool, logger log.FieldLogger) error {
 	if !controllerutils.HasFinalizer(pool, finalizer) {
 		return nil
 	}
-	_, unClaimedCDs, err := r.getAllClusterDeploymentsForPool(pool, logger)
+	// Don't care about the poolVersion here since we're deleting everything.
+	cds, err := getAllClusterDeploymentsForPool(r.Client, pool, "", logger)
 	if err != nil {
 		return err
 	}
-	for _, cd := range unClaimedCDs {
+	for _, cd := range append(cds.Assignable(), cds.Installing()...) {
 		if cd.DeletionTimestamp != nil {
 			continue
 		}
-		if err := r.Delete(context.Background(), cd); err != nil {
+		if err := cds.Delete(r.Client, cd.Name); err != nil {
 			logger.WithError(err).WithField("cluster", cd.Name).Log(controllerutils.LogLevel(err), "could not delete ClusterDeployment")
 			return errors.Wrap(err, "could not delete ClusterDeployment")
 		}
@@ -686,26 +758,6 @@ func (r *ReconcileClusterPool) reconcileDeletedPool(pool *hivev1.ClusterPool, lo
 	return nil
 }
 
-func (r *ReconcileClusterPool) getAllClusterDeploymentsForPool(pool *hivev1.ClusterPool, logger log.FieldLogger) (claimed, unclaimed []*hivev1.ClusterDeployment, err error) {
-	cdList := &hivev1.ClusterDeploymentList{}
-	if err := r.Client.List(context.Background(), cdList); err != nil {
-		logger.WithError(err).Error("error listing ClusterDeployments")
-		return nil, nil, err
-	}
-	for i, cd := range cdList.Items {
-		if refInCD := cd.Spec.ClusterPoolRef; refInCD != nil {
-			if refInCD.Namespace == pool.Namespace && refInCD.PoolName == pool.Name {
-				if len(refInCD.ClaimName) > 0 {
-					claimed = append(claimed, &cdList.Items[i])
-				} else {
-					unclaimed = append(unclaimed, &cdList.Items[i])
-				}
-			}
-		}
-	}
-	return claimed, unclaimed, nil
-}
-
 func poolReference(pool *hivev1.ClusterPool) hivev1.ClusterPoolReference {
 	return hivev1.ClusterPoolReference{
 		Namespace: pool.Namespace,
@@ -874,6 +926,7 @@ func (r *ReconcileClusterPool) createCloudBuilder(pool *hivev1.ClusterPool, logg
 		cloudBuilder := clusterresource.NewAzureCloudBuilderFromSecret(credsSecret)
 		cloudBuilder.BaseDomainResourceGroupName = platform.Azure.BaseDomainResourceGroupName
 		cloudBuilder.Region = platform.Azure.Region
+		cloudBuilder.CloudName = platform.Azure.CloudName
 		return cloudBuilder, nil
 	// TODO: OpenStack, VMware, and Ovirt.
 	default:
@@ -881,76 +934,3 @@ func (r *ReconcileClusterPool) createCloudBuilder(pool *hivev1.ClusterPool, logg
 		return nil, errors.New("unsupported platform")
 	}
 }
-
-// getAllPendingClusterClaims returns all of the ClusterClaims that are requesting clusters from the specified pool.
-// The claims are returned in order of creation time, from oldest to youngest.
-func (r *ReconcileClusterPool) getAllPendingClusterClaims(pool *hivev1.ClusterPool, logger log.FieldLogger) ([]*hivev1.ClusterClaim, error) {
-	claimsList := &hivev1.ClusterClaimList{}
-	if err := r.Client.List(context.Background(), claimsList, client.InNamespace(pool.Namespace)); err != nil {
-		logger.WithError(err).Error("error listing ClusterClaims")
-		return nil, err
-	}
-	var pendingClaims []*hivev1.ClusterClaim
-	for i, claim := range claimsList.Items {
-		// skip claims for other pools
-		if claim.Spec.ClusterPoolName != pool.Name {
-			continue
-		}
-		// skip claims that have been assigned already
-		if claim.Spec.Namespace != "" {
-			continue
-		}
-		pendingClaims = append(pendingClaims, &claimsList.Items[i])
-	}
-	sort.Slice(
-		pendingClaims,
-		func(i, j int) bool {
-			return pendingClaims[i].CreationTimestamp.Before(&pendingClaims[j].CreationTimestamp)
-		},
-	)
-	return pendingClaims, nil
-}
-
-func (r *ReconcileClusterPool) assignClustersToClaims(claims []*hivev1.ClusterClaim, cds []*hivev1.ClusterDeployment, logger log.FieldLogger) ([]*hivev1.ClusterDeployment, error) {
-	for _, claim := range claims {
-		logger := logger.WithField("claim", claim.Name)
-		var conds []hivev1.ClusterClaimCondition
-		var statusChanged bool
-		if len(cds) > 0 {
-			claim.Spec.Namespace = cds[0].Namespace
-			cds = cds[1:]
-			logger.WithField("cluster", claim.Spec.Namespace).Info("assigning cluster to claim")
-			if err := r.Update(context.Background(), claim); err != nil {
-				logger.WithError(err).Log(controllerutils.LogLevel(err), "could not assign cluster to claim")
-				return cds, err
-			}
-			conds = controllerutils.SetClusterClaimCondition(
-				claim.Status.Conditions,
-				hivev1.ClusterClaimPendingCondition,
-				corev1.ConditionTrue,
-				"ClusterAssigned",
-				"Cluster assigned to ClusterClaim, awaiting claim",
-				controllerutils.UpdateConditionIfReasonOrMessageChange,
-			)
-			statusChanged = true
-		} else {
-			logger.Debug("no clusters ready to assign to claim")
-			conds, statusChanged = controllerutils.SetClusterClaimConditionWithChangeCheck(
-				claim.Status.Conditions,
-				hivev1.ClusterClaimPendingCondition,
-				corev1.ConditionTrue,
-				"NoClusters",
-				"No clusters in pool are ready to be claimed",
-				controllerutils.UpdateConditionIfReasonOrMessageChange,
-			)
-		}
-		if statusChanged {
-			claim.Status.Conditions = conds
-			if err := r.Status().Update(context.Background(), claim); err != nil {
-				logger.WithError(err).Log(controllerutils.LogLevel(err), "could not update status of ClusterClaim")
-				return cds, err
-			}
-		}
-	}
-	return cds, nil
-}
