@@ -17,17 +17,17 @@ import (
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	"k8s.io/apimachinery/pkg/types"
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
 
 	oappsv1 "github.com/openshift/api/apps/v1"
 	"github.com/openshift/library-go/pkg/operator/events"
 	"github.com/openshift/library-go/pkg/operator/resource/resourceread"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	"github.com/openshift/hive/pkg/constants"
 	hiveconstants "github.com/openshift/hive/pkg/constants"
 	"github.com/openshift/hive/pkg/controller/images"
+	"github.com/openshift/hive/pkg/controller/utils"
 	"github.com/openshift/hive/pkg/operator/assets"
 	"github.com/openshift/hive/pkg/operator/util"
 	"github.com/openshift/hive/pkg/resource"
@@ -44,6 +44,8 @@ const (
 	// hiveConfigHashAnnotation is annotation on hivedeployment that contains
 	// the hash of the contents of the hive-controllers-config configmap
 	hiveConfigHashAnnotation = "hive.openshift.io/hiveconfig-hash"
+
+	hiveClusterSyncStatefulSetSpecHashAnnotation = "hive.openshift.io/clustersync-statefulset-spec-hash"
 )
 
 var (
@@ -98,6 +100,7 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 	}
 
 	addManagedDomainsVolume(&hiveDeployment.Spec.Template.Spec, mdConfigMap.Name)
+	addAWSPrivateLinkConfigVolume(&hiveDeployment.Spec.Template.Spec)
 
 	hiveNSName := getHiveNamespace(instance)
 
@@ -130,6 +133,13 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 		hiveContainer.Env = append(hiveContainer.Env, awsLogsEnvVars...)
 	}
 
+	if awssp := instance.Spec.ServiceProviderCredentialsConfig.AWS; awssp != nil && awssp.CredentialsSecretRef.Name != "" {
+		hiveContainer.Env = append(hiveContainer.Env, corev1.EnvVar{
+			Name:  constants.HiveAWSServiceProviderCredentialsSecretRefEnvVar,
+			Value: awssp.CredentialsSecretRef.Name,
+		})
+	}
+
 	if zoneCheckDNSServers := os.Getenv(dnsServersEnvVar); len(zoneCheckDNSServers) > 0 {
 		dnsServersEnvVar := corev1.EnvVar{
 			Name:  dnsServersEnvVar,
@@ -156,6 +166,24 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 		}
 	}
 
+	if instance.Spec.ArgoCD.Enabled {
+		hLog.Infof("ArgoCD integration enabled")
+		tmpEnvVar := corev1.EnvVar{
+			Name:  hiveconstants.ArgoCDEnvVar,
+			Value: "true",
+		}
+		hiveContainer.Env = append(hiveContainer.Env, tmpEnvVar)
+	}
+
+	if instance.Spec.ArgoCD.Namespace != "" {
+		hLog.Infof("ArgoCD namespace specified in hiveconfig")
+		tmpEnvVar := corev1.EnvVar{
+			Name:  hiveconstants.ArgoCDNamespaceEnvVar,
+			Value: instance.Spec.ArgoCD.Namespace,
+		}
+		hiveContainer.Env = append(hiveContainer.Env, tmpEnvVar)
+	}
+
 	if instance.Spec.DeprovisionsDisabled != nil && *instance.Spec.DeprovisionsDisabled {
 		hLog.Info("deprovisions disabled in hiveconfig")
 		tmpEnvVar := corev1.EnvVar{
@@ -182,6 +210,17 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 		})
 	}
 
+	if instance.Spec.ReleaseImageVerificationConfigMapRef != nil {
+		hLog.Info("Release Image verification enabled")
+		hiveContainer.Env = append(hiveContainer.Env, corev1.EnvVar{
+			Name:  hiveconstants.HiveReleaseImageVerificationConfigMapNamespaceEnvVar,
+			Value: instance.Spec.ReleaseImageVerificationConfigMapRef.Namespace,
+		}, corev1.EnvVar{
+			Name:  hiveconstants.HiveReleaseImageVerificationConfigMapNameEnvVar,
+			Value: instance.Spec.ReleaseImageVerificationConfigMapRef.Name,
+		})
+	}
+
 	if err := r.includeAdditionalCAs(hLog, h, instance, hiveDeployment); err != nil {
 		return err
 	}
@@ -198,6 +237,10 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 		hiveDeployment.Spec.Template.Annotations = make(map[string]string, 1)
 	}
 	hiveDeployment.Spec.Template.Annotations[hiveConfigHashAnnotation] = hiveControllersConfigHash
+	hiveDeployment.Spec.Template.Annotations[hiveConfigHashAnnotation] = hiveControllersConfigHash
+
+	utils.SetProxyEnvVars(&hiveDeployment.Spec.Template.Spec,
+		os.Getenv("HTTP_PROXY"), os.Getenv("HTTPS_PROXY"), os.Getenv("NO_PROXY"))
 
 	// Load namespaced assets, decode them, set to our target namespace, and apply:
 	namespacedAssets := []string{
@@ -267,6 +310,10 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 		hLog.Warn("hive is not running on OpenShift, some optional assets will not be deployed")
 	}
 
+	// Apply nodeSelector and tolerations passed through from the operator deployment
+	hiveDeployment.Spec.Template.Spec.NodeSelector = r.nodeSelector
+	hiveDeployment.Spec.Template.Spec.Tolerations = r.tolerations
+
 	hiveDeployment.Namespace = hiveNSName
 	result, err := util.ApplyRuntimeObjectWithGC(h, hiveDeployment, instance)
 	if err != nil {
@@ -282,8 +329,7 @@ func (r *ReconcileHiveConfig) deployHive(hLog log.FieldLogger, h resource.Helper
 func (r *ReconcileHiveConfig) includeAdditionalCAs(hLog log.FieldLogger, h resource.Helper, instance *hivev1.HiveConfig, hiveDeployment *appsv1.Deployment) error {
 	additionalCA := &bytes.Buffer{}
 	for _, clientCARef := range instance.Spec.AdditionalCertificateAuthoritiesSecretRef {
-		caSecret := &corev1.Secret{}
-		err := r.Get(context.TODO(), types.NamespacedName{Namespace: getHiveNamespace(instance), Name: clientCARef.Name}, caSecret)
+		caSecret, err := r.hiveSecretLister.Secrets(getHiveNamespace(instance)).Get(clientCARef.Name)
 		if err != nil {
 			hLog.WithError(err).WithField("secret", clientCARef.Name).Errorf("Cannot read client CA secret")
 			continue
@@ -296,8 +342,7 @@ func (r *ReconcileHiveConfig) includeAdditionalCAs(hLog log.FieldLogger, h resou
 	}
 
 	if additionalCA.Len() == 0 {
-		caSecret := &corev1.Secret{}
-		err := r.Get(context.TODO(), types.NamespacedName{Namespace: getHiveNamespace(instance), Name: hiveAdditionalCASecret}, caSecret)
+		caSecret, err := r.hiveSecretLister.Secrets(getHiveNamespace(instance)).Get(hiveAdditionalCASecret)
 		if err == nil {
 			err = r.Delete(context.TODO(), caSecret)
 			if err != nil {
