@@ -25,9 +25,9 @@ import (
 	"github.com/openshift/library-go/pkg/operator/events"
 	"github.com/openshift/library-go/pkg/operator/resource/resourceread"
 
-	admregv1 "k8s.io/api/admissionregistration/v1beta1"
+	admregv1 "k8s.io/api/admissionregistration/v1"
 	corev1 "k8s.io/api/core/v1"
-	apiextv1beta1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
+	apiextv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/sets"
@@ -140,7 +140,7 @@ func (r *ReconcileHiveConfig) deployHiveAdmission(hLog log.FieldLogger, h resour
 	validatingWebhooks := make([]*admregv1.ValidatingWebhookConfiguration, len(webhookAssets))
 	for i, yaml := range webhookAssets {
 		asset = assets.MustAsset(yaml)
-		wh := util.ReadValidatingWebhookConfigurationV1Beta1OrDie(asset, scheme.Scheme)
+		wh := util.ReadValidatingWebhookConfigurationV1OrDie(asset, scheme.Scheme)
 		validatingWebhooks[i] = wh
 	}
 
@@ -187,6 +187,10 @@ func (r *ReconcileHiveConfig) deployHiveAdmission(hLog log.FieldLogger, h resour
 	}
 	hiveAdmDeployment.Spec.Template.Annotations[servingCertSecretHashAnnotation] = certSecretHash
 
+	// Apply nodeSelector and tolerations passed through from the operator deployment
+	hiveAdmDeployment.Spec.Template.Spec.NodeSelector = r.nodeSelector
+	hiveAdmDeployment.Spec.Template.Spec.Tolerations = r.tolerations
+
 	result, err := util.ApplyRuntimeObjectWithGC(h, hiveAdmDeployment, instance)
 	if err != nil {
 		hLog.WithError(err).Error("error applying deployment")
@@ -287,7 +291,7 @@ func (r *ReconcileHiveConfig) injectCerts(apiService *apiregistrationv1.APIServi
 // is311 returns true if this is a 3.11 OpenShift cluster. We check by looking for a ClusterVersion CRD,
 // which should only exist on OpenShift 4.x. We do not expect Hive to ever be deployed on pre-3.11.
 func (r *ReconcileHiveConfig) is311(hLog log.FieldLogger) (bool, error) {
-	cvCRD := &apiextv1beta1.CustomResourceDefinition{}
+	cvCRD := &apiextv1.CustomResourceDefinition{}
 	err := r.Client.Get(context.Background(), types.NamespacedName{Name: clusterVersionCRDName}, cvCRD)
 	if err != nil && errors.IsNotFound(err) {
 		// If this CRD does not exist, we must not be on a 4.x cluster.
@@ -354,7 +358,7 @@ func (r *ReconcileHiveConfig) deploySupportedContractsConfigMap(hLog log.FieldLo
 		supported[k.Name] = k.Supported
 	}
 
-	crdList := &apiextv1beta1.CustomResourceDefinitionList{}
+	crdList := &apiextv1.CustomResourceDefinitionList{}
 	if err := r.Client.List(context.TODO(), crdList); err != nil {
 		hLog.WithError(err).Error("error getting crds for collect contract implementations")
 		return "", err
