@@ -18,10 +18,10 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
 	openshiftapiv1 "github.com/openshift/api/config/v1"
+	machineapi "github.com/openshift/api/machine/v1beta1"
 	routev1 "github.com/openshift/api/route/v1"
 	autoscalingv1 "github.com/openshift/cluster-autoscaler-operator/pkg/apis/autoscaling/v1"
 	autoscalingv1beta1 "github.com/openshift/cluster-autoscaler-operator/pkg/apis/autoscaling/v1beta1"
-	machineapi "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 
 	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	"github.com/openshift/hive/pkg/constants"
@@ -168,7 +168,7 @@ func SetUnreachableCondition(cd *hivev1.ClusterDeployment, connectionError error
 	if connectionError != nil {
 		status = corev1.ConditionTrue
 		reason = "ErrorConnectingToCluster"
-		message = connectionError.Error()
+		message = utils.ErrorScrub(connectionError)
 		updateCheck = utils.UpdateConditionIfReasonOrMessageChange
 	}
 	cd.Status.Conditions, changed = utils.SetClusterDeploymentConditionWithChangeCheck(
